==> haskell-ansi-terminal-types-0.11.5-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-7XqF2qX4RkPGJi29d6VYkq
key:                  ansi-terminal-types-0.11.5-7XqF2qX4RkPGJi29d6VYkq
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  5bc380effe6d745e09f4e4f6b1d21b2f
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-7XqF2qX4RkPGJi29d6VYkq
depends:              base-4.17.2.1 colour-2.3.6-3V03SgFmiQ0JR2lOdVTqAL
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-types-0.11.5-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-EWYTMzAAilBGwp1uOVWKpz
key:                  ansi-terminal-types-0.11.5-EWYTMzAAilBGwp1uOVWKpz
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  8226ce8eed690f997dbc246564bb7d6b
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-EWYTMzAAilBGwp1uOVWKpz
depends:              base-4.17.2.1 colour-2.3.6-FIgDdqoL5o6H1LR4GaFueC
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
